@@ -12,8 +12,8 @@ from ... import getsms as lib_customer
 
 
 import json
-
 import pika
+import logging
 
 
 @api.route('/sms', methods=['POST'])
@@ -70,53 +70,89 @@ def send_sms():
         description: Erreur de connection au SMSC
     """
     auth = request.authorization
-    if auth:
+    try:
+        customer = lib_customer.Getsms()
+        result = customer.verify_token(auth.username)
         auth = (auth.username, auth.password)
-    params = request.args or {}
-    headers = request.headers or {}
-    json_doc = request.get_json() or {}
-    sender_id = json_doc.get('sender_id', 'bip')
-    try:
-        queue = CONFIG[sender_id]['account']
     except KeyError:
-        queue = CONFIG['bip']['account']
-    document = {
-        'auth': auth or (),
-        'params': params,
-        'headers': headers,
-        'json': json_doc
-        }
-    try:
-        connection = pika.BlockingConnection(
-            pika.ConnectionParameters(
-                host='localhost',
-                virtual_host='/smsc'
-                )
-            )
-    except Exception:
-        # exception de connection lancée par pika
-        # il faut que rabbitmq-server soit installé
-        # et que le vhost /{service} existe déjà
         return internal_error(
-            message="serveur RabbitMQ injoignable",
+            message="Erreur Interne",
             code='{}-5000'.format(SERVICE_CODE),
             service_code=SERVICE_CODE
             )
     else:
-        channel = connection.channel()
-        channel.exchange_declare(
-            exchange='sendsms',
-            exchange_type='topic'
-            )
-        # déclaration idempotente: pas grave si l'exchange existe déjà
-        channel.basic_publish(
-            exchange='sendsms',
-            routing_key=queue,
-            body=json.dumps(document),
-            properties=pika.BasicProperties(delivery_mode=2)
-            )
-        connection.close()
-        return success(service_code=SERVICE_CODE)
+        # if result.status_code == 200:
+        user = result.json()['message'][0]
+        logging.warn(user)
+        params = request.args or {}
+        headers = request.headers or {}
+        json_doc = request.get_json() or {}
+        if user.startswith('partenaire'):
+            sender_id = user.split('_')[1]
+        else:
+            sender_id = json_doc.get('sender_id', 'unknown')
+        try:
+            logging.warn(sender_id)
+            json_doc['sender_id'] = sender_id
+            queue = CONFIG[sender_id]['account']
+        except KeyError:
+            return bad_request(
+                message="Le sender_id n'exist pas",
+                code='{}-{}'.format(
+                    SERVICE_CODE,
+                    '4001'
+                    ),
+                service_code=SERVICE_CODE
+                )
+            # queue = CONFIG['bip']['account']
+        document = {
+            'auth': auth or (),
+            'params': params,
+            'headers': headers,
+            'json': json_doc
+            }
+        try:
+            connection = pika.BlockingConnection(
+                pika.ConnectionParameters(
+                    host='localhost',
+                    virtual_host='/smsc'
+                    )
+                )
+        except Exception:
+            # exception de connection lancée par pika
+            # il faut que rabbitmq-server soit installé
+            # et que le vhost /{service} existe déjà
+            return internal_error(
+                message="serveur RabbitMQ injoignable",
+                code='{}-5000'.format(SERVICE_CODE),
+                service_code=SERVICE_CODE
+                )
+        else:
+            channel = connection.channel()
+            channel.exchange_declare(
+                exchange='sendsms',
+                exchange_type='topic'
+                )
+            # déclaration idempotente: pas grave si l'exchange existe déjà
+            channel.basic_publish(
+                exchange='sendsms',
+                routing_key=queue,
+                body=json.dumps(document),
+                properties=pika.BasicProperties(delivery_mode=2)
+                )
+            connection.close()
+            return success(service_code=SERVICE_CODE)
+        """else:
+            return bad_request(
+                message="Le token inactif veuillez "
+                "prendre un nouveau jeton",
+                code='{}-{}'.format(
+                    SERVICE_CODE,
+                    '400'
+                    ),
+                service_code=SERVICE_CODE
+                )
+        """
 
 
 @api.route('/sms/<string:uuid>', methods=['GET'])
@@ -216,6 +252,71 @@ def get_sms(uuid):
     return jsonify(infos)
 
 
+@api.route('/sms/delivery', methods=['GET'])
+def get_delivery_sms():
+    """
+    Lecture des SMS.
+    Cette ressource contacte le SMSC pour Lire des SMS
+    ---
+    tags:
+      - sms
+    components:
+      securitySchemes:
+        basicAuth:
+          type: http
+          scheme: basic
+    security:
+      - basicAuth: []
+    parameters:
+      - name: start
+        in: body
+        required: false
+        description: date de debut de recup des sms
+        schema:
+          type: date
+      - name: stop
+        in: body
+        required: false
+        description: date de fin de recup des sms
+        schema:
+          type: string
+      - name: bool_sms
+        in: body
+        required: false
+        description: check les sms deja lu
+        schema:
+          type: booleen
+    responses:
+      200:
+        description: La demande de lecture de SMS a été comprise par le SMSC
+      400:
+        description: Les paramètres en entrée sont incorrects
+      503:
+        description: Le SMSC met trop de temps à répondre
+      504:
+        description: Erreur de connection au SMSC
+    """
+    customer = lib_customer.Getsms()
+    msisdn = request.args.get('msisdn', None)
+    request_id = request.args.get('request_id', None)
+    if not request_id:
+        return bad_request(
+                  message='Le format request_id '
+                          'est incorrect ',
+                  code='{}-{}'.format(
+                      SERVICE_CODE,
+                      '4001'
+                      ),
+                  service_code=SERVICE_CODE
+                  )
+    else:
+        infos = customer.delivery_sms(
+            request_id,
+            msisdn
+            )
+    return jsonify(infos)
+
+
 @api.route('/sms/<string:uuid>', methods=['PUT'])
 def update_sms(uuid):
     """
