@@ -15,6 +15,7 @@ import smpplib.exceptions
 import smpplib.smpp
 import smpplib.gsm
 import sys
+import requests
 
 __all__ = [
     'Getsms',
@@ -25,17 +26,28 @@ class Getsms(object):
 
     def __init__(self, name='261391761246'):
         self.msisdn = str(name)
-        smpp_config = 'GETSMS_{}'.format(str(name))
+        smpp_config = 'SMPP_{}'.format(str(name))
         self.host = CONFIG[smpp_config]['host']
         self.port = CONFIG[smpp_config]['port']
         self.username = CONFIG[smpp_config]['username']
         self.password = CONFIG[smpp_config]['password']
+        self.api_url = CONFIG['server']['host']
         LOGS.logger.info(self.msisdn)
 
     def all(msisdn):
         name = '{}'.format(str(msisdn))
         return [Getsms(name)]
 
+    def verify_token(self, token):
+        api_url = '{}/auth/verify-token'.format(
+            self.api_url
+            )
+        result = requests.post(
+            api_url,
+            auth=(token, '')
+            )
+        return result
+
     def connect_receiver_sms(self):
         smpp_client = smpplib.client.Client(
             self.host,
@@ -121,6 +133,72 @@ class Getsms(object):
                 res += ' '
         return res
 
+    def delivery_sms(self, request_id, msisdn=None):
+        LOGS.logger.info(
+            "Recuperation le status des sms "
+            "du {msisdn} request_id {request_id}".format(
+                msisdn=msisdn,
+                request_id=request_id
+                )
+            )
+        sms = {'nbr': 0}
+        kwargs = {
+            'engine': CONFIG['db']['engine'],
+            'user': CONFIG['db']['user'],
+            'password': CONFIG['db']['password'],
+            'host': CONFIG['db']['host'],
+            'port': CONFIG['db']['port'],
+            'name': CONFIG['db']['database']
+            }
+        url = self.database_url(**kwargs)
+        infos = []
+        with records.Database(url) as db:
+            if msisdn is not None:
+                sql = (
+                    "SELECT * FROM get_delivery_sms "
+                    "WHERE request_id = :request_id "
+                    "AND msisdn = :msisdn "
+                    )
+                rows = db.query(
+                    sql,
+                    request_id=str(request_id),
+                    msisdn=str(msisdn[-9:])
+                    )
+            else:
+                sql = (
+                    "SELECT * FROM get_delivery_sms "
+                    "WHERE request_id = :request_id "
+                    )
+                rows = db.query(
+                    sql,
+                    request_id=str(request_id)
+                    )
+            for row in rows:
+                if row.code == '000':
+                    code = '200'
+                else:
+                    code = '500'
+                infos.append({
+                        'date': row.create_date,
+                        'submit_date': row.submit_date.strip(),
+                        'done_date': row.done_date.strip(),
+                        'status': row.status,
+                        'code': code,
+                        'msisdn_dest': row.msisdn,
+                        'msisdn_source': row.msisdn_source
+                        })
+            nbr = len(infos)
+            infos = sorted(
+                infos,
+                key=lambda x: x['date']
+                )
+            for i in infos:
+                del i['date']
+            sms['sms'] = list(infos)
+            sms['nbr'] = nbr
+        LOGS.logger.info("Recuperation de {} sms".format(nbr))
+        return sms
+
     def check_sms(
             self,
             start=None,
